@@ -10,6 +10,7 @@
 
 #include "screenmapper.h"
 
+#include <QMap>
 #include <QScreen>
 #include <QTimer>
 
@@ -268,14 +269,25 @@ void ScreenMapper::setScreenMapping(const QStringList &mapping)
     const int sizeOfParamGroup = useDefaultActivity ? 2 : 3; // Match screenMapping()
 
     newMap.reserve(count / sizeOfParamGroup);
+    QMap<int, int> screenConsistencyMap;
     for (int i = 0; i < count - (sizeOfParamGroup - 1); i += sizeOfParamGroup) {
         if (i + (sizeOfParamGroup - 1) < count) {
             const QUrl url = QUrl::fromUserInput(mapping[i], {}, QUrl::AssumeLocalFile);
             const QString activity = useDefaultActivity ? KActivities::Consumer().currentActivity() : mapping[i + 2];
             newMap[std::make_pair(url, activity)] = mapping[i + 1].toInt();
+            screenConsistencyMap[mapping[i + 1].toInt()] = -1;
         }
     }
 
+    int lastMappedScreen = 0;
+    for (int key : screenConsistencyMap.keys()) {
+        screenConsistencyMap[key] = lastMappedScreen++;
+    }
+
+    for (auto it = newMap.begin(); it != newMap.end(); it++) {
+        newMap[it.key()] = screenConsistencyMap.value(it.value());
+    }
+
     if (m_screenItemMap != newMap) {
         m_screenItemMap = newMap;
         Q_EMIT screenMappingChanged();
@@ -316,6 +328,7 @@ QStringList ScreenMapper::disabledScreensMap() const
 
 void ScreenMapper::readDisabledScreensMap(const QStringList &serializedMap)
 {
+    decltype(m_itemsOnDisabledScreensMap) tempItemsOnDisabledScreensMap;
     m_itemsOnDisabledScreensMap.clear();
     bool readingScreenId = true;
     bool readingActivityId = true;
@@ -323,9 +336,13 @@ void ScreenMapper::readDisabledScreensMap(const QStringList &serializedMap)
     int screenId = -1;
     QString activityId;
     int vectorCounter = 0;
+
+    QMap<int, int> screenConsistencyMap;
+
     for (const auto &entry : serializedMap) {
         if (readingScreenId) {
             screenId = entry.toInt();
+            screenConsistencyMap[screenId] = -1;
             readingScreenId = false;
         } else if (readingActivityId) {
             // Missing activity ID in the old config before 5.25
@@ -341,9 +358,9 @@ void ScreenMapper::readDisabledScreensMap(const QStringList &serializedMap)
         } else {
             const auto url = stringToUrl(entry);
             const auto pair = std::make_pair(screenId, activityId);
-            auto urlVectorIt = m_itemsOnDisabledScreensMap.find(pair);
-            if (urlVectorIt == m_itemsOnDisabledScreensMap.end()) {
-                m_itemsOnDisabledScreensMap[pair] = {url};
+            auto urlVectorIt = tempItemsOnDisabledScreensMap.find(pair);
+            if (urlVectorIt == tempItemsOnDisabledScreensMap.end()) {
+                tempItemsOnDisabledScreensMap[pair] = {url};
             } else {
                 urlVectorIt->append(url);
             }
@@ -357,6 +374,22 @@ void ScreenMapper::readDisabledScreensMap(const QStringList &serializedMap)
             }
         }
     }
+
+    // Find out what is the max screen number that was found in the saved screenMapping config key
+    int maxKnownScreen = -1;
+    for (auto it = m_screenItemMap.constBegin(); it != m_screenItemMap.constEnd(); it++) {
+        maxKnownScreen = std::max(maxKnownScreen, it.value());
+    }
+
+    // Make sure everything in disabled screens is numbered progressively from the first screen number that wasn't found in the saved screenMapping config key
+    int lastMappedScreen = maxKnownScreen + 1;
+    for (int key : screenConsistencyMap.keys()) {
+        screenConsistencyMap[key] = lastMappedScreen++;
+    }
+    for (auto it = tempItemsOnDisabledScreensMap.constBegin(); it != tempItemsOnDisabledScreensMap.constEnd(); it++) {
+        const auto newKey = std::pair<int, QString>(screenConsistencyMap.value(it.key().first), it.key().second);
+        m_itemsOnDisabledScreensMap[newKey] = it.value();
+    }
 }
 
 void ScreenMapper::saveDisabledScreensMap() const
