@@ -287,31 +287,35 @@ void JoyWidget::checkDevice()
     JoyDevice::EventType type;
     int number, value;
 
-    if (!joydev->getEvent(type, number, value))
+    // sleep-wait for the first event
+    if (!joydev->getEvent(type, number, value, true))
         return;
 
-    if (type == JoyDevice::BUTTON) {
-        if (!buttonTbl->item(number, 0))
-            buttonTbl->setItem(number, 0, new QTableWidgetItem());
+    // process all pending events
+    do {
+        if (type == JoyDevice::BUTTON) {
+            if (!buttonTbl->item(number, 0))
+                buttonTbl->setItem(number, 0, new QTableWidgetItem());
 
-        if (value == 0) // button release
-            buttonTbl->item(number, 0)->setText(QStringLiteral("-"));
-        else
-            buttonTbl->item(number, 0)->setText(i18n("PRESSED"));
-    }
+            if (value == 0) // button release
+                buttonTbl->item(number, 0)->setText(QStringLiteral("-"));
+            else
+                buttonTbl->item(number, 0)->setText(i18n("PRESSED"));
+        }
 
-    if (type == JoyDevice::AXIS) {
-        if (number == 0) // x-axis
-            xyPos->changeX(value);
+        if (type == JoyDevice::AXIS) {
+            if (number == 0) // x-axis
+                xyPos->changeX(value);
 
-        if (number == 1) // y-axis
-            xyPos->changeY(value);
+            if (number == 1) // y-axis
+                xyPos->changeY(value);
 
-        if (!axesTbl->item(number, 0))
-            axesTbl->setItem(number, 0, new QTableWidgetItem());
+            if (!axesTbl->item(number, 0))
+                axesTbl->setItem(number, 0, new QTableWidgetItem());
 
-        axesTbl->item(number, 0)->setText(QStringLiteral("%1").arg(int(value)));
-    }
+            axesTbl->item(number, 0)->setText(QStringLiteral("%1").arg(int(value)));
+        }
+    } while (joydev->getEvent(type, number, value, false)); // return immediately when no events are left
 }
 
 void JoyWidget::calibrateDevice()
