@@ -5,8 +5,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KCM_KEYBOARD_WIDGET_H_
-#define KCM_KEYBOARD_WIDGET_H_
+#pragma once
 
 #include "ui_kcm_keyboard.h"
 
@@ -85,7 +84,7 @@ private:
     void updateHardwareUI(const QString &model);
     void updateLayoutsUI();
     void updateShortcutsUI();
-    void updateSwitcingPolicyUI(KeyboardConfig::SwitchingPolicy policy);
+    void updateSwitchingPolicyUI(KeyboardConfig::SwitchingPolicy policy);
     void updateXkbShortcutButton(const QString &groupName, QPushButton *button);
     void clearXkbGroup(const QString &groupName);
     void moveSelectedLayouts(int shift);
@@ -97,8 +96,6 @@ private:
     QStringList xkbOptionsFromUI() const;
 
     QString keyboardModelFromUI() const;
-    KeyboardConfig::SwitchingPolicy switcingPolicyFromUI() const;
+    KeyboardConfig::SwitchingPolicy switchingPolicyFromUI() const;
     void setDefaultIndicatorVisible(QWidget *widget, bool visible);
 };
-
-#endif /* KCM_KEYBOARD_WIDGET_H_ */
