@@ -11,13 +11,16 @@
 
 #include <KApplicationTrader>
 #include <KConfigGroup>
+#include <KDesktopFile>
 #include <KGlobalAccel>
 #include <KGlobalShortcutInfo>
 #include <KLocalizedString>
 #include <KService>
+#include <kdesktopfile.h>
 #include <kglobalaccel_component_interface.h>
 #include <kglobalaccel_interface.h>
 
+#include "basemodel.h"
 #include "kcmkeys_debug.h"
 
 static QStringList buildActionId(const QString &componentUnique, const QString &componentFriendly, const QString &actionUnique, const QString &actionFriendly)
@@ -98,7 +101,10 @@ Component GlobalAccelModel::loadComponent(const QList<KGlobalShortcutInfo> &info
     KService::Ptr service = KService::serviceByStorageId(componentUnique);
     // Not a normal desktop file but maybe specific file in kglobalaccel dir
     if (!service && componentUnique.endsWith(QLatin1String(".desktop"))) {
-        service = new KService(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kglobalaccel/") + componentUnique));
+        service = new KService(QStandardPaths::locate(QStandardPaths::ApplicationsLocation, componentUnique));
+        if (!service) {
+            service = new KService(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kglobalaccel/") + componentUnique));
+        }
     }
 
     if (!service) {
@@ -110,7 +116,9 @@ Component GlobalAccelModel::loadComponent(const QList<KGlobalShortcutInfo> &info
         const KService::List services = KApplicationTrader::query(filter);
         service = services.value(0, KService::Ptr());
     }
-    const QString type = service && service->isApplication() ? i18n("Applications") : i18n("System Services");
+    bool isCommandShortcut = service && service->property(QStringLiteral("X-KDE-GlobalAccel-CommandShortcut"), QMetaType::Bool).toBool();
+    const ComponentType type =
+        service && service->isApplication() ? (isCommandShortcut ? ComponentType::Command : ComponentType::Application) : ComponentType::SystemService;
     QString icon;
 
     static const QHash<QString, QString> hardCodedIcons = {
@@ -123,6 +131,8 @@ Component GlobalAccelModel::loadComponent(const QList<KGlobalShortcutInfo> &info
         icon = service->icon();
     } else if (hardCodedIcons.contains(componentUnique)) {
         icon = hardCodedIcons[componentUnique];
+    } else if (type == ComponentType::Command) {
+        icon = QStringLiteral("system-run");
     } else {
         icon = componentUnique;
     }
@@ -263,6 +273,10 @@ void GlobalAccelModel::addApplication(const QString &desktopFileName, const QStr
         desktopName = info.fileName();
     }
 
+    KDesktopFile desktopFile(desktopName);
+    KConfigGroup cg = desktopFile.desktopGroup();
+    ComponentType type = cg.readEntry<bool>(QStringLiteral("X-KDE-GlobalAccel-CommandShortcut"), false) ? ComponentType::Command : ComponentType::Application;
+
     // Register a dummy action to trigger kglobalaccel to parse the desktop file
     QStringList actionId = buildActionId(desktopName, displayName, QString(), QString());
     m_globalAccelInterface->doRegister(actionId);
@@ -271,7 +285,7 @@ void GlobalAccelModel::addApplication(const QString &desktopFileName, const QStr
     collator.setCaseSensitivity(Qt::CaseInsensitive);
     collator.setNumericMode(true);
     auto pos = std::lower_bound(m_components.begin(), m_components.end(), displayName, [&](const Component &c, const QString &name) {
-        return c.type != i18n("System Services") && collator.compare(c.displayName, name) < 0;
+        return c.type != ComponentType::SystemService && (c.type != type ? c.type < type : collator.compare(c.displayName, name) < 0);
     });
     auto watcher = new QDBusPendingCallWatcher(m_globalAccelInterface->getComponent(desktopName));
     connect(watcher, &QDBusPendingCallWatcher::finished, this, [=] {
